"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5318 import (
        AbstractAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5319 import (
        AbstractShaftCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5320 import (
        AbstractShaftOrHousingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5321 import (
        AbstractShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5322 import (
        AGMAGleasonConicalGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5323 import (
        AGMAGleasonConicalGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5324 import (
        AGMAGleasonConicalGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5325 import (
        AssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5326 import (
        BearingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5327 import (
        BeltConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5328 import (
        BeltDriveCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5329 import (
        BevelDifferentialGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5330 import (
        BevelDifferentialGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5331 import (
        BevelDifferentialGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5332 import (
        BevelDifferentialPlanetGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5333 import (
        BevelDifferentialSunGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5334 import (
        BevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5335 import (
        BevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5336 import (
        BevelGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5337 import (
        BoltCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5338 import (
        BoltedJointCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5339 import (
        ClutchCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5340 import (
        ClutchConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5341 import (
        ClutchHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5342 import (
        CoaxialConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5343 import (
        ComponentCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5344 import (
        ConceptCouplingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5345 import (
        ConceptCouplingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5346 import (
        ConceptCouplingHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5347 import (
        ConceptGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5348 import (
        ConceptGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5349 import (
        ConceptGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5350 import (
        ConicalGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5351 import (
        ConicalGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5352 import (
        ConicalGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5353 import (
        ConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5354 import (
        ConnectorCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5355 import (
        CouplingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5356 import (
        CouplingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5357 import (
        CouplingHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5358 import (
        CVTBeltConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5359 import (
        CVTCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5360 import (
        CVTPulleyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5361 import (
        CycloidalAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5362 import (
        CycloidalDiscCentralBearingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5363 import (
        CycloidalDiscCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5364 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5365 import (
        CylindricalGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5366 import (
        CylindricalGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5367 import (
        CylindricalGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5368 import (
        CylindricalPlanetGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5369 import (
        DatumCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5370 import (
        ExternalCADModelCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5371 import (
        FaceGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5372 import (
        FaceGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5373 import (
        FaceGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5374 import (
        FEPartCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5375 import (
        FlexiblePinAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5376 import (
        GearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5377 import (
        GearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5378 import (
        GearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5379 import (
        GuideDxfModelCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5380 import (
        HypoidGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5381 import (
        HypoidGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5382 import (
        HypoidGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5383 import (
        InterMountableComponentConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5384 import (
        KlingelnbergCycloPalloidConicalGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5385 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5386 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5387 import (
        KlingelnbergCycloPalloidHypoidGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5388 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5389 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5390 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5391 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5392 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5393 import (
        MassDiscCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5394 import (
        MeasurementComponentCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5395 import (
        MicrophoneArrayCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5396 import (
        MicrophoneCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5397 import (
        MountableComponentCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5398 import (
        OilSealCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5399 import (
        PartCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5400 import (
        PartToPartShearCouplingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5401 import (
        PartToPartShearCouplingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5402 import (
        PartToPartShearCouplingHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5403 import (
        PlanetaryConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5404 import (
        PlanetaryGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5405 import (
        PlanetCarrierCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5406 import (
        PointLoadCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5407 import (
        PowerLoadCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5408 import (
        PulleyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5409 import (
        RingPinsCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5410 import (
        RingPinsToDiscConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5411 import (
        RollingRingAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5412 import (
        RollingRingCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5413 import (
        RollingRingConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5414 import (
        RootAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5415 import (
        ShaftCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5416 import (
        ShaftHubConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5417 import (
        ShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5418 import (
        SpecialisedAssemblyCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5419 import (
        SpiralBevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5420 import (
        SpiralBevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5421 import (
        SpiralBevelGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5422 import (
        SpringDamperCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5423 import (
        SpringDamperConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5424 import (
        SpringDamperHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5425 import (
        StraightBevelDiffGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5426 import (
        StraightBevelDiffGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5427 import (
        StraightBevelDiffGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5428 import (
        StraightBevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5429 import (
        StraightBevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5430 import (
        StraightBevelGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5431 import (
        StraightBevelPlanetGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5432 import (
        StraightBevelSunGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5433 import (
        SynchroniserCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5434 import (
        SynchroniserHalfCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5435 import (
        SynchroniserPartCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5436 import (
        SynchroniserSleeveCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5437 import (
        TorqueConverterCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5438 import (
        TorqueConverterConnectionCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5439 import (
        TorqueConverterPumpCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5440 import (
        TorqueConverterTurbineCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5441 import (
        UnbalancedMassCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5442 import (
        VirtualComponentCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5443 import (
        WormGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5444 import (
        WormGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5445 import (
        WormGearSetCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5446 import (
        ZerolBevelGearCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5447 import (
        ZerolBevelGearMeshCompoundModalAnalysisAtAStiffness,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5448 import (
        ZerolBevelGearSetCompoundModalAnalysisAtAStiffness,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5318": [
            "AbstractAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5319": [
            "AbstractShaftCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5320": [
            "AbstractShaftOrHousingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5321": [
            "AbstractShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5322": [
            "AGMAGleasonConicalGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5323": [
            "AGMAGleasonConicalGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5324": [
            "AGMAGleasonConicalGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5325": [
            "AssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5326": [
            "BearingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5327": [
            "BeltConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5328": [
            "BeltDriveCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5329": [
            "BevelDifferentialGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5330": [
            "BevelDifferentialGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5331": [
            "BevelDifferentialGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5332": [
            "BevelDifferentialPlanetGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5333": [
            "BevelDifferentialSunGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5334": [
            "BevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5335": [
            "BevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5336": [
            "BevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5337": [
            "BoltCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5338": [
            "BoltedJointCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5339": [
            "ClutchCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5340": [
            "ClutchConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5341": [
            "ClutchHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5342": [
            "CoaxialConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5343": [
            "ComponentCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5344": [
            "ConceptCouplingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5345": [
            "ConceptCouplingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5346": [
            "ConceptCouplingHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5347": [
            "ConceptGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5348": [
            "ConceptGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5349": [
            "ConceptGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5350": [
            "ConicalGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5351": [
            "ConicalGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5352": [
            "ConicalGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5353": [
            "ConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5354": [
            "ConnectorCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5355": [
            "CouplingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5356": [
            "CouplingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5357": [
            "CouplingHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5358": [
            "CVTBeltConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5359": [
            "CVTCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5360": [
            "CVTPulleyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5361": [
            "CycloidalAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5362": [
            "CycloidalDiscCentralBearingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5363": [
            "CycloidalDiscCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5364": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5365": [
            "CylindricalGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5366": [
            "CylindricalGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5367": [
            "CylindricalGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5368": [
            "CylindricalPlanetGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5369": [
            "DatumCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5370": [
            "ExternalCADModelCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5371": [
            "FaceGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5372": [
            "FaceGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5373": [
            "FaceGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5374": [
            "FEPartCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5375": [
            "FlexiblePinAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5376": [
            "GearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5377": [
            "GearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5378": [
            "GearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5379": [
            "GuideDxfModelCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5380": [
            "HypoidGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5381": [
            "HypoidGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5382": [
            "HypoidGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5383": [
            "InterMountableComponentConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5384": [
            "KlingelnbergCycloPalloidConicalGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5385": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5386": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5387": [
            "KlingelnbergCycloPalloidHypoidGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5388": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5389": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5390": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5391": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5392": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5393": [
            "MassDiscCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5394": [
            "MeasurementComponentCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5395": [
            "MicrophoneArrayCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5396": [
            "MicrophoneCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5397": [
            "MountableComponentCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5398": [
            "OilSealCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5399": [
            "PartCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5400": [
            "PartToPartShearCouplingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5401": [
            "PartToPartShearCouplingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5402": [
            "PartToPartShearCouplingHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5403": [
            "PlanetaryConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5404": [
            "PlanetaryGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5405": [
            "PlanetCarrierCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5406": [
            "PointLoadCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5407": [
            "PowerLoadCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5408": [
            "PulleyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5409": [
            "RingPinsCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5410": [
            "RingPinsToDiscConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5411": [
            "RollingRingAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5412": [
            "RollingRingCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5413": [
            "RollingRingConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5414": [
            "RootAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5415": [
            "ShaftCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5416": [
            "ShaftHubConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5417": [
            "ShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5418": [
            "SpecialisedAssemblyCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5419": [
            "SpiralBevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5420": [
            "SpiralBevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5421": [
            "SpiralBevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5422": [
            "SpringDamperCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5423": [
            "SpringDamperConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5424": [
            "SpringDamperHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5425": [
            "StraightBevelDiffGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5426": [
            "StraightBevelDiffGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5427": [
            "StraightBevelDiffGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5428": [
            "StraightBevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5429": [
            "StraightBevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5430": [
            "StraightBevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5431": [
            "StraightBevelPlanetGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5432": [
            "StraightBevelSunGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5433": [
            "SynchroniserCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5434": [
            "SynchroniserHalfCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5435": [
            "SynchroniserPartCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5436": [
            "SynchroniserSleeveCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5437": [
            "TorqueConverterCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5438": [
            "TorqueConverterConnectionCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5439": [
            "TorqueConverterPumpCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5440": [
            "TorqueConverterTurbineCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5441": [
            "UnbalancedMassCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5442": [
            "VirtualComponentCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5443": [
            "WormGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5444": [
            "WormGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5445": [
            "WormGearSetCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5446": [
            "ZerolBevelGearCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5447": [
            "ZerolBevelGearMeshCompoundModalAnalysisAtAStiffness"
        ],
        "_private.system_model.analyses_and_results.modal_analyses_at_a_stiffness.compound._5448": [
            "ZerolBevelGearSetCompoundModalAnalysisAtAStiffness"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundModalAnalysisAtAStiffness",
    "AbstractShaftCompoundModalAnalysisAtAStiffness",
    "AbstractShaftOrHousingCompoundModalAnalysisAtAStiffness",
    "AbstractShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness",
    "AGMAGleasonConicalGearCompoundModalAnalysisAtAStiffness",
    "AGMAGleasonConicalGearMeshCompoundModalAnalysisAtAStiffness",
    "AGMAGleasonConicalGearSetCompoundModalAnalysisAtAStiffness",
    "AssemblyCompoundModalAnalysisAtAStiffness",
    "BearingCompoundModalAnalysisAtAStiffness",
    "BeltConnectionCompoundModalAnalysisAtAStiffness",
    "BeltDriveCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialGearCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialGearMeshCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialGearSetCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialPlanetGearCompoundModalAnalysisAtAStiffness",
    "BevelDifferentialSunGearCompoundModalAnalysisAtAStiffness",
    "BevelGearCompoundModalAnalysisAtAStiffness",
    "BevelGearMeshCompoundModalAnalysisAtAStiffness",
    "BevelGearSetCompoundModalAnalysisAtAStiffness",
    "BoltCompoundModalAnalysisAtAStiffness",
    "BoltedJointCompoundModalAnalysisAtAStiffness",
    "ClutchCompoundModalAnalysisAtAStiffness",
    "ClutchConnectionCompoundModalAnalysisAtAStiffness",
    "ClutchHalfCompoundModalAnalysisAtAStiffness",
    "CoaxialConnectionCompoundModalAnalysisAtAStiffness",
    "ComponentCompoundModalAnalysisAtAStiffness",
    "ConceptCouplingCompoundModalAnalysisAtAStiffness",
    "ConceptCouplingConnectionCompoundModalAnalysisAtAStiffness",
    "ConceptCouplingHalfCompoundModalAnalysisAtAStiffness",
    "ConceptGearCompoundModalAnalysisAtAStiffness",
    "ConceptGearMeshCompoundModalAnalysisAtAStiffness",
    "ConceptGearSetCompoundModalAnalysisAtAStiffness",
    "ConicalGearCompoundModalAnalysisAtAStiffness",
    "ConicalGearMeshCompoundModalAnalysisAtAStiffness",
    "ConicalGearSetCompoundModalAnalysisAtAStiffness",
    "ConnectionCompoundModalAnalysisAtAStiffness",
    "ConnectorCompoundModalAnalysisAtAStiffness",
    "CouplingCompoundModalAnalysisAtAStiffness",
    "CouplingConnectionCompoundModalAnalysisAtAStiffness",
    "CouplingHalfCompoundModalAnalysisAtAStiffness",
    "CVTBeltConnectionCompoundModalAnalysisAtAStiffness",
    "CVTCompoundModalAnalysisAtAStiffness",
    "CVTPulleyCompoundModalAnalysisAtAStiffness",
    "CycloidalAssemblyCompoundModalAnalysisAtAStiffness",
    "CycloidalDiscCentralBearingConnectionCompoundModalAnalysisAtAStiffness",
    "CycloidalDiscCompoundModalAnalysisAtAStiffness",
    "CycloidalDiscPlanetaryBearingConnectionCompoundModalAnalysisAtAStiffness",
    "CylindricalGearCompoundModalAnalysisAtAStiffness",
    "CylindricalGearMeshCompoundModalAnalysisAtAStiffness",
    "CylindricalGearSetCompoundModalAnalysisAtAStiffness",
    "CylindricalPlanetGearCompoundModalAnalysisAtAStiffness",
    "DatumCompoundModalAnalysisAtAStiffness",
    "ExternalCADModelCompoundModalAnalysisAtAStiffness",
    "FaceGearCompoundModalAnalysisAtAStiffness",
    "FaceGearMeshCompoundModalAnalysisAtAStiffness",
    "FaceGearSetCompoundModalAnalysisAtAStiffness",
    "FEPartCompoundModalAnalysisAtAStiffness",
    "FlexiblePinAssemblyCompoundModalAnalysisAtAStiffness",
    "GearCompoundModalAnalysisAtAStiffness",
    "GearMeshCompoundModalAnalysisAtAStiffness",
    "GearSetCompoundModalAnalysisAtAStiffness",
    "GuideDxfModelCompoundModalAnalysisAtAStiffness",
    "HypoidGearCompoundModalAnalysisAtAStiffness",
    "HypoidGearMeshCompoundModalAnalysisAtAStiffness",
    "HypoidGearSetCompoundModalAnalysisAtAStiffness",
    "InterMountableComponentConnectionCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidConicalGearCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidConicalGearSetCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidHypoidGearCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundModalAnalysisAtAStiffness",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundModalAnalysisAtAStiffness",
    "MassDiscCompoundModalAnalysisAtAStiffness",
    "MeasurementComponentCompoundModalAnalysisAtAStiffness",
    "MicrophoneArrayCompoundModalAnalysisAtAStiffness",
    "MicrophoneCompoundModalAnalysisAtAStiffness",
    "MountableComponentCompoundModalAnalysisAtAStiffness",
    "OilSealCompoundModalAnalysisAtAStiffness",
    "PartCompoundModalAnalysisAtAStiffness",
    "PartToPartShearCouplingCompoundModalAnalysisAtAStiffness",
    "PartToPartShearCouplingConnectionCompoundModalAnalysisAtAStiffness",
    "PartToPartShearCouplingHalfCompoundModalAnalysisAtAStiffness",
    "PlanetaryConnectionCompoundModalAnalysisAtAStiffness",
    "PlanetaryGearSetCompoundModalAnalysisAtAStiffness",
    "PlanetCarrierCompoundModalAnalysisAtAStiffness",
    "PointLoadCompoundModalAnalysisAtAStiffness",
    "PowerLoadCompoundModalAnalysisAtAStiffness",
    "PulleyCompoundModalAnalysisAtAStiffness",
    "RingPinsCompoundModalAnalysisAtAStiffness",
    "RingPinsToDiscConnectionCompoundModalAnalysisAtAStiffness",
    "RollingRingAssemblyCompoundModalAnalysisAtAStiffness",
    "RollingRingCompoundModalAnalysisAtAStiffness",
    "RollingRingConnectionCompoundModalAnalysisAtAStiffness",
    "RootAssemblyCompoundModalAnalysisAtAStiffness",
    "ShaftCompoundModalAnalysisAtAStiffness",
    "ShaftHubConnectionCompoundModalAnalysisAtAStiffness",
    "ShaftToMountableComponentConnectionCompoundModalAnalysisAtAStiffness",
    "SpecialisedAssemblyCompoundModalAnalysisAtAStiffness",
    "SpiralBevelGearCompoundModalAnalysisAtAStiffness",
    "SpiralBevelGearMeshCompoundModalAnalysisAtAStiffness",
    "SpiralBevelGearSetCompoundModalAnalysisAtAStiffness",
    "SpringDamperCompoundModalAnalysisAtAStiffness",
    "SpringDamperConnectionCompoundModalAnalysisAtAStiffness",
    "SpringDamperHalfCompoundModalAnalysisAtAStiffness",
    "StraightBevelDiffGearCompoundModalAnalysisAtAStiffness",
    "StraightBevelDiffGearMeshCompoundModalAnalysisAtAStiffness",
    "StraightBevelDiffGearSetCompoundModalAnalysisAtAStiffness",
    "StraightBevelGearCompoundModalAnalysisAtAStiffness",
    "StraightBevelGearMeshCompoundModalAnalysisAtAStiffness",
    "StraightBevelGearSetCompoundModalAnalysisAtAStiffness",
    "StraightBevelPlanetGearCompoundModalAnalysisAtAStiffness",
    "StraightBevelSunGearCompoundModalAnalysisAtAStiffness",
    "SynchroniserCompoundModalAnalysisAtAStiffness",
    "SynchroniserHalfCompoundModalAnalysisAtAStiffness",
    "SynchroniserPartCompoundModalAnalysisAtAStiffness",
    "SynchroniserSleeveCompoundModalAnalysisAtAStiffness",
    "TorqueConverterCompoundModalAnalysisAtAStiffness",
    "TorqueConverterConnectionCompoundModalAnalysisAtAStiffness",
    "TorqueConverterPumpCompoundModalAnalysisAtAStiffness",
    "TorqueConverterTurbineCompoundModalAnalysisAtAStiffness",
    "UnbalancedMassCompoundModalAnalysisAtAStiffness",
    "VirtualComponentCompoundModalAnalysisAtAStiffness",
    "WormGearCompoundModalAnalysisAtAStiffness",
    "WormGearMeshCompoundModalAnalysisAtAStiffness",
    "WormGearSetCompoundModalAnalysisAtAStiffness",
    "ZerolBevelGearCompoundModalAnalysisAtAStiffness",
    "ZerolBevelGearMeshCompoundModalAnalysisAtAStiffness",
    "ZerolBevelGearSetCompoundModalAnalysisAtAStiffness",
)



"""SteadyStateSynchronousResponseOptions"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.list_with_selected_item import (
    promote_to_list_with_selected_item,
)
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.sentinels import ListWithSelectedItem_None
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private import _0
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import list_with_selected_item
from mastapy._private.system_model.part_model import _2748

_STEADY_STATE_SYNCHRONOUS_RESPONSE_OPTIONS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponses",
    "SteadyStateSynchronousResponseOptions",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="SteadyStateSynchronousResponseOptions")
    CastSelf = TypeVar(
        "CastSelf",
        bound="SteadyStateSynchronousResponseOptions._Cast_SteadyStateSynchronousResponseOptions",
    )


__docformat__ = "restructuredtext en"
__all__ = ("SteadyStateSynchronousResponseOptions",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_SteadyStateSynchronousResponseOptions:
    """Special nested class for casting SteadyStateSynchronousResponseOptions to subclasses."""

    __parent__: "SteadyStateSynchronousResponseOptions"

    @property
    def steady_state_synchronous_response_options(
        self: "CastSelf",
    ) -> "SteadyStateSynchronousResponseOptions":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class SteadyStateSynchronousResponseOptions(_0.APIBase):
    """SteadyStateSynchronousResponseOptions

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _STEADY_STATE_SYNCHRONOUS_RESPONSE_OPTIONS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def end_speed(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "EndSpeed")

        if temp is None:
            return 0.0

        return temp

    @end_speed.setter
    @exception_bridge
    @enforce_parameter_types
    def end_speed(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "EndSpeed", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def include_damping_effects(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "IncludeDampingEffects")

        if temp is None:
            return False

        return temp

    @include_damping_effects.setter
    @exception_bridge
    @enforce_parameter_types
    def include_damping_effects(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "IncludeDampingEffects",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def include_disk_skew_effects(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "IncludeDiskSkewEffects")

        if temp is None:
            return False

        return temp

    @include_disk_skew_effects.setter
    @exception_bridge
    @enforce_parameter_types
    def include_disk_skew_effects(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "IncludeDiskSkewEffects",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def include_gyroscopic_effects(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "IncludeGyroscopicEffects")

        if temp is None:
            return False

        return temp

    @include_gyroscopic_effects.setter
    @exception_bridge
    @enforce_parameter_types
    def include_gyroscopic_effects(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "IncludeGyroscopicEffects",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def include_shaft_bow_effects(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "IncludeShaftBowEffects")

        if temp is None:
            return False

        return temp

    @include_shaft_bow_effects.setter
    @exception_bridge
    @enforce_parameter_types
    def include_shaft_bow_effects(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "IncludeShaftBowEffects",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def include_unbalanced_effects(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "IncludeUnbalancedEffects")

        if temp is None:
            return False

        return temp

    @include_unbalanced_effects.setter
    @exception_bridge
    @enforce_parameter_types
    def include_unbalanced_effects(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "IncludeUnbalancedEffects",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def number_of_speeds(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(self.wrapped, "NumberOfSpeeds")

        if temp is None:
            return 0

        return temp

    @number_of_speeds.setter
    @exception_bridge
    @enforce_parameter_types
    def number_of_speeds(self: "Self", value: "int") -> None:
        pythonnet_property_set(
            self.wrapped, "NumberOfSpeeds", int(value) if value is not None else 0
        )

    @property
    @exception_bridge
    def reference_power_load(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_PowerLoad":
        """ListWithSelectedItem[mastapy.system_model.part_model.PowerLoad]"""
        temp = pythonnet_property_get(self.wrapped, "ReferencePowerLoad")

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_PowerLoad",
        )(temp)

    @reference_power_load.setter
    @exception_bridge
    @enforce_parameter_types
    def reference_power_load(self: "Self", value: "_2748.PowerLoad") -> None:
        generic_type = (
            list_with_selected_item.ListWithSelectedItem_PowerLoad.implicit_type()
        )
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(self.wrapped, "ReferencePowerLoad", value)

    @property
    @exception_bridge
    def start_speed(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "StartSpeed")

        if temp is None:
            return 0.0

        return temp

    @start_speed.setter
    @exception_bridge
    @enforce_parameter_types
    def start_speed(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "StartSpeed", float(value) if value is not None else 0.0
        )

    @property
    def cast_to(self: "Self") -> "_Cast_SteadyStateSynchronousResponseOptions":
        """Cast to another type.

        Returns:
            _Cast_SteadyStateSynchronousResponseOptions
        """
        return _Cast_SteadyStateSynchronousResponseOptions(self)



"""CylindricalMisalignmentCalculator"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)
from mastapy._private._math.vector_3d import Vector3D

from mastapy._private import _0
from mastapy._private._internal import conversion, utility

_CYLINDRICAL_MISALIGNMENT_CALCULATOR = python_net_import(
    "SMT.MastaAPI.NodalAnalysis", "CylindricalMisalignmentCalculator"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar("Self", bound="CylindricalMisalignmentCalculator")
    CastSelf = TypeVar(
        "CastSelf",
        bound="CylindricalMisalignmentCalculator._Cast_CylindricalMisalignmentCalculator",
    )


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalMisalignmentCalculator",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CylindricalMisalignmentCalculator:
    """Special nested class for casting CylindricalMisalignmentCalculator to subclasses."""

    __parent__: "CylindricalMisalignmentCalculator"

    @property
    def cylindrical_misalignment_calculator(
        self: "CastSelf",
    ) -> "CylindricalMisalignmentCalculator":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class CylindricalMisalignmentCalculator(_0.APIBase):
    """CylindricalMisalignmentCalculator

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CYLINDRICAL_MISALIGNMENT_CALCULATOR

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def gear_a_equivalent_misalignment_for_rating(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "GearAEquivalentMisalignmentForRating"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_a_line_fit_misalignment(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearALineFitMisalignment")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_a_line_fit_misalignment_angle(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearALineFitMisalignmentAngle")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_a_radial_angular_component_of_rigid_body_misalignment(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "GearARadialAngularComponentOfRigidBodyMisalignment"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_a_rigid_body_misalignment(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearARigidBodyMisalignment")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_a_rigid_body_misalignment_angle(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearARigidBodyMisalignmentAngle")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_a_rigid_body_out_of_plane_misalignment(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "GearARigidBodyOutOfPlaneMisalignment"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_a_rigid_body_out_of_plane_misalignment_angle(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "GearARigidBodyOutOfPlaneMisalignmentAngle"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_a_single_node_misalignment_angle_due_to_tilt(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "GearASingleNodeMisalignmentAngleDueToTilt"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_a_single_node_misalignment_due_to_tilt(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "GearASingleNodeMisalignmentDueToTilt"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_a_single_node_misalignment_due_to_twist(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "GearASingleNodeMisalignmentDueToTwist"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_a_tangential_angular_component_of_rigid_body_misalignment(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "GearATangentialAngularComponentOfRigidBodyMisalignment"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_a_transverse_separations(self: "Self") -> "List[float]":
        """List[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearATransverseSeparations")

        if temp is None:
            return None

        value = conversion.to_list_any(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def gear_b_equivalent_misalignment_for_rating(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "GearBEquivalentMisalignmentForRating"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_b_line_fit_misalignment(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearBLineFitMisalignment")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_b_line_fit_misalignment_angle(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearBLineFitMisalignmentAngle")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_b_radial_angular_component_of_rigid_body_misalignment(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "GearBRadialAngularComponentOfRigidBodyMisalignment"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_b_rigid_body_misalignment(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearBRigidBodyMisalignment")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_b_rigid_body_misalignment_angle(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearBRigidBodyMisalignmentAngle")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_b_rigid_body_out_of_plane_misalignment(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "GearBRigidBodyOutOfPlaneMisalignment"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_b_rigid_body_out_of_plane_misalignment_angle(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "GearBRigidBodyOutOfPlaneMisalignmentAngle"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_b_single_node_misalignment_angle_due_to_tilt(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "GearBSingleNodeMisalignmentAngleDueToTilt"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_b_single_node_misalignment_due_to_tilt(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "GearBSingleNodeMisalignmentDueToTilt"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_b_single_node_misalignment_due_to_twist(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "GearBSingleNodeMisalignmentDueToTwist"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_b_tangential_angular_component_of_rigid_body_misalignment(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "GearBTangentialAngularComponentOfRigidBodyMisalignment"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def gear_b_transverse_separations(self: "Self") -> "List[float]":
        """List[float]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearBTransverseSeparations")

        if temp is None:
            return None

        value = conversion.to_list_any(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def total_equivalent_misalignment_for_rating(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "TotalEquivalentMisalignmentForRating"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def total_line_fit_misalignment(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TotalLineFitMisalignment")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def total_line_fit_misalignment_angle(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TotalLineFitMisalignmentAngle")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def total_radial_angular_component_of_rigid_body_misalignment(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "TotalRadialAngularComponentOfRigidBodyMisalignment"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def total_rigid_body_misalignment(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TotalRigidBodyMisalignment")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def total_rigid_body_misalignment_angle(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TotalRigidBodyMisalignmentAngle")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def total_rigid_body_out_of_plane_misalignment(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "TotalRigidBodyOutOfPlaneMisalignment"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def total_rigid_body_out_of_plane_misalignment_angle(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "TotalRigidBodyOutOfPlaneMisalignmentAngle"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def total_single_node_misalignment(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TotalSingleNodeMisalignment")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def total_single_node_misalignment_angle_due_to_tilt(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "TotalSingleNodeMisalignmentAngleDueToTilt"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def total_single_node_misalignment_due_to_tilt(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "TotalSingleNodeMisalignmentDueToTilt"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def total_single_node_misalignment_due_to_twist(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "TotalSingleNodeMisalignmentDueToTwist"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def total_tangential_angular_component_of_rigid_body_misalignment(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "TotalTangentialAngularComponentOfRigidBodyMisalignment"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def rigid_body_coordinate_system_x_axis(self: "Self") -> "Vector3D":
        """Vector3D

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RigidBodyCoordinateSystemXAxis")

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector3d(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def rigid_body_coordinate_system_y_axis(self: "Self") -> "Vector3D":
        """Vector3D

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RigidBodyCoordinateSystemYAxis")

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector3d(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_CylindricalMisalignmentCalculator":
        """Cast to another type.

        Returns:
            _Cast_CylindricalMisalignmentCalculator
        """
        return _Cast_CylindricalMisalignmentCalculator(self)



"""ToothFlankFractureAnalysisContactPointN1457"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)
from mastapy._private._math.vector_2d import Vector2D

from mastapy._private import _0
from mastapy._private._internal import constructor, conversion, utility

_TOOTH_FLANK_FRACTURE_ANALYSIS_CONTACT_POINT_N1457 = python_net_import(
    "SMT.MastaAPI.Gears.Rating.Cylindrical.ISO6336",
    "ToothFlankFractureAnalysisContactPointN1457",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.gear_designs.cylindrical import _1157
    from mastapy._private.gears.rating.cylindrical.iso6336 import _643

    Self = TypeVar("Self", bound="ToothFlankFractureAnalysisContactPointN1457")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ToothFlankFractureAnalysisContactPointN1457._Cast_ToothFlankFractureAnalysisContactPointN1457",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ToothFlankFractureAnalysisContactPointN1457",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ToothFlankFractureAnalysisContactPointN1457:
    """Special nested class for casting ToothFlankFractureAnalysisContactPointN1457 to subclasses."""

    __parent__: "ToothFlankFractureAnalysisContactPointN1457"

    @property
    def tooth_flank_fracture_analysis_row_n1457(
        self: "CastSelf",
    ) -> "_643.ToothFlankFractureAnalysisRowN1457":
        from mastapy._private.gears.rating.cylindrical.iso6336 import _643

        return self.__parent__._cast(_643.ToothFlankFractureAnalysisRowN1457)

    @property
    def tooth_flank_fracture_analysis_contact_point_n1457(
        self: "CastSelf",
    ) -> "ToothFlankFractureAnalysisContactPointN1457":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ToothFlankFractureAnalysisContactPointN1457(_0.APIBase):
    """ToothFlankFractureAnalysisContactPointN1457

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _TOOTH_FLANK_FRACTURE_ANALYSIS_CONTACT_POINT_N1457

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def half_of_hertzian_contact_width(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "HalfOfHertzianContactWidth")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def hertzian_contact_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "HertzianContactStress")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def mean_coefficient_of_friction(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MeanCoefficientOfFriction")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def coordinates(self: "Self") -> "Vector2D":
        """Vector2D

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Coordinates")

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector2d(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def position_on_profile(self: "Self") -> "_1157.CylindricalGearProfileMeasurement":
        """mastapy.gears.gear_designs.cylindrical.CylindricalGearProfileMeasurement

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PositionOnProfile")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_ToothFlankFractureAnalysisContactPointN1457":
        """Cast to another type.

        Returns:
            _Cast_ToothFlankFractureAnalysisContactPointN1457
        """
        return _Cast_ToothFlankFractureAnalysisContactPointN1457(self)



"""AGMAGleasonConicalGearSetCompoundMultibodyDynamicsAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import conversion, utility
from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
    _5904,
)

_AGMA_GLEASON_CONICAL_GEAR_SET_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses.Compound",
    "AGMAGleasonConicalGearSetCompoundMultibodyDynamicsAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7941,
        _7944,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses import _5718
    from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
        _5870,
        _5883,
        _5888,
        _5930,
        _5934,
        _5951,
        _5970,
        _5973,
        _5979,
        _5982,
        _6000,
    )

    Self = TypeVar(
        "Self", bound="AGMAGleasonConicalGearSetCompoundMultibodyDynamicsAnalysis"
    )
    CastSelf = TypeVar(
        "CastSelf",
        bound="AGMAGleasonConicalGearSetCompoundMultibodyDynamicsAnalysis._Cast_AGMAGleasonConicalGearSetCompoundMultibodyDynamicsAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("AGMAGleasonConicalGearSetCompoundMultibodyDynamicsAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_AGMAGleasonConicalGearSetCompoundMultibodyDynamicsAnalysis:
    """Special nested class for casting AGMAGleasonConicalGearSetCompoundMultibodyDynamicsAnalysis to subclasses."""

    __parent__: "AGMAGleasonConicalGearSetCompoundMultibodyDynamicsAnalysis"

    @property
    def conical_gear_set_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5904.ConicalGearSetCompoundMultibodyDynamicsAnalysis":
        return self.__parent__._cast(
            _5904.ConicalGearSetCompoundMultibodyDynamicsAnalysis
        )

    @property
    def gear_set_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5930.GearSetCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5930,
        )

        return self.__parent__._cast(_5930.GearSetCompoundMultibodyDynamicsAnalysis)

    @property
    def specialised_assembly_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5970.SpecialisedAssemblyCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5970,
        )

        return self.__parent__._cast(
            _5970.SpecialisedAssemblyCompoundMultibodyDynamicsAnalysis
        )

    @property
    def abstract_assembly_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5870.AbstractAssemblyCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5870,
        )

        return self.__parent__._cast(
            _5870.AbstractAssemblyCompoundMultibodyDynamicsAnalysis
        )

    @property
    def part_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5951.PartCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5951,
        )

        return self.__parent__._cast(_5951.PartCompoundMultibodyDynamicsAnalysis)

    @property
    def part_compound_analysis(self: "CastSelf") -> "_7944.PartCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7944,
        )

        return self.__parent__._cast(_7944.PartCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7941.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7941,
        )

        return self.__parent__._cast(_7941.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def bevel_differential_gear_set_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5883.BevelDifferentialGearSetCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5883,
        )

        return self.__parent__._cast(
            _5883.BevelDifferentialGearSetCompoundMultibodyDynamicsAnalysis
        )

    @property
    def bevel_gear_set_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5888.BevelGearSetCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5888,
        )

        return self.__parent__._cast(
            _5888.BevelGearSetCompoundMultibodyDynamicsAnalysis
        )

    @property
    def hypoid_gear_set_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5934.HypoidGearSetCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5934,
        )

        return self.__parent__._cast(
            _5934.HypoidGearSetCompoundMultibodyDynamicsAnalysis
        )

    @property
    def spiral_bevel_gear_set_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5973.SpiralBevelGearSetCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5973,
        )

        return self.__parent__._cast(
            _5973.SpiralBevelGearSetCompoundMultibodyDynamicsAnalysis
        )

    @property
    def straight_bevel_diff_gear_set_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5979.StraightBevelDiffGearSetCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5979,
        )

        return self.__parent__._cast(
            _5979.StraightBevelDiffGearSetCompoundMultibodyDynamicsAnalysis
        )

    @property
    def straight_bevel_gear_set_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5982.StraightBevelGearSetCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5982,
        )

        return self.__parent__._cast(
            _5982.StraightBevelGearSetCompoundMultibodyDynamicsAnalysis
        )

    @property
    def zerol_bevel_gear_set_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_6000.ZerolBevelGearSetCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _6000,
        )

        return self.__parent__._cast(
            _6000.ZerolBevelGearSetCompoundMultibodyDynamicsAnalysis
        )

    @property
    def agma_gleason_conical_gear_set_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "AGMAGleasonConicalGearSetCompoundMultibodyDynamicsAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class AGMAGleasonConicalGearSetCompoundMultibodyDynamicsAnalysis(
    _5904.ConicalGearSetCompoundMultibodyDynamicsAnalysis
):
    """AGMAGleasonConicalGearSetCompoundMultibodyDynamicsAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = (
        _AGMA_GLEASON_CONICAL_GEAR_SET_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS
    )

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def assembly_analysis_cases(
        self: "Self",
    ) -> "List[_5718.AGMAGleasonConicalGearSetMultibodyDynamicsAnalysis]":
        """List[mastapy.system_model.analyses_and_results.mbd_analyses.AGMAGleasonConicalGearSetMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyAnalysisCases")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def assembly_analysis_cases_ready(
        self: "Self",
    ) -> "List[_5718.AGMAGleasonConicalGearSetMultibodyDynamicsAnalysis]":
        """List[mastapy.system_model.analyses_and_results.mbd_analyses.AGMAGleasonConicalGearSetMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyAnalysisCasesReady")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_AGMAGleasonConicalGearSetCompoundMultibodyDynamicsAnalysis":
        """Cast to another type.

        Returns:
            _Cast_AGMAGleasonConicalGearSetCompoundMultibodyDynamicsAnalysis
        """
        return _Cast_AGMAGleasonConicalGearSetCompoundMultibodyDynamicsAnalysis(self)



"""ThreeDChartDefinition"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.utility_gui.charts import _2098

_THREE_D_CHART_DEFINITION = python_net_import(
    "SMT.MastaAPI.UtilityGUI.Charts", "ThreeDChartDefinition"
)

if TYPE_CHECKING:
    from typing import Any, List, Tuple, Type, TypeVar

    from mastapy._private.utility.report import _1972, _1977
    from mastapy._private.utility_gui.charts import _2100

    Self = TypeVar("Self", bound="ThreeDChartDefinition")
    CastSelf = TypeVar(
        "CastSelf", bound="ThreeDChartDefinition._Cast_ThreeDChartDefinition"
    )


__docformat__ = "restructuredtext en"
__all__ = ("ThreeDChartDefinition",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ThreeDChartDefinition:
    """Special nested class for casting ThreeDChartDefinition to subclasses."""

    __parent__: "ThreeDChartDefinition"

    @property
    def nd_chart_definition(self: "CastSelf") -> "_2098.NDChartDefinition":
        return self.__parent__._cast(_2098.NDChartDefinition)

    @property
    def chart_definition(self: "CastSelf") -> "_1977.ChartDefinition":
        from mastapy._private.utility.report import _1977

        return self.__parent__._cast(_1977.ChartDefinition)

    @property
    def three_d_chart_definition(self: "CastSelf") -> "ThreeDChartDefinition":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ThreeDChartDefinition(_2098.NDChartDefinition):
    """ThreeDChartDefinition

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _THREE_D_CHART_DEFINITION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def z_axis(self: "Self") -> "_1972.AxisSettings":
        """mastapy.utility.report.AxisSettings

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ZAxis")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def x_axis_range(self: "Self") -> "Tuple[float, float]":
        """Tuple[float, float]"""
        temp = pythonnet_property_get(self.wrapped, "XAxisRange")

        if temp is None:
            return None

        value = conversion.pn_to_mp_range(temp)

        if value is None:
            return None

        return value

    @x_axis_range.setter
    @exception_bridge
    @enforce_parameter_types
    def x_axis_range(self: "Self", value: "Tuple[float, float]") -> None:
        value = conversion.mp_to_pn_range(value)
        pythonnet_property_set(self.wrapped, "XAxisRange", value)

    @property
    @exception_bridge
    def y_axis_range(self: "Self") -> "Tuple[float, float]":
        """Tuple[float, float]"""
        temp = pythonnet_property_get(self.wrapped, "YAxisRange")

        if temp is None:
            return None

        value = conversion.pn_to_mp_range(temp)

        if value is None:
            return None

        return value

    @y_axis_range.setter
    @exception_bridge
    @enforce_parameter_types
    def y_axis_range(self: "Self", value: "Tuple[float, float]") -> None:
        value = conversion.mp_to_pn_range(value)
        pythonnet_property_set(self.wrapped, "YAxisRange", value)

    @property
    @exception_bridge
    def z_axis_range(self: "Self") -> "Tuple[float, float]":
        """Tuple[float, float]"""
        temp = pythonnet_property_get(self.wrapped, "ZAxisRange")

        if temp is None:
            return None

        value = conversion.pn_to_mp_range(temp)

        if value is None:
            return None

        return value

    @z_axis_range.setter
    @exception_bridge
    @enforce_parameter_types
    def z_axis_range(self: "Self", value: "Tuple[float, float]") -> None:
        value = conversion.mp_to_pn_range(value)
        pythonnet_property_set(self.wrapped, "ZAxisRange", value)

    @exception_bridge
    def data_points_for_surfaces(self: "Self") -> "List[_2100.PointsForSurface]":
        """List[mastapy.utility_gui.charts.PointsForSurface]"""
        return conversion.pn_to_mp_objects_in_list(
            pythonnet_method_call(self.wrapped, "DataPointsForSurfaces")
        )

    @property
    def cast_to(self: "Self") -> "_Cast_ThreeDChartDefinition":
        """Cast to another type.

        Returns:
            _Cast_ThreeDChartDefinition
        """
        return _Cast_ThreeDChartDefinition(self)



"""Module for handling deprecation or obsoletion."""

from __future__ import annotations

import functools
import warnings


class ObsoleteException(Exception):
    """Simple exception for obsolete methods."""


def deprecated(alternative: str = ""):
    """Mark a method as deprecated.

    Args:
        alternative (str, optional): A simple message describing the
            alternative implementation to the deprecated method. Default is
            an empty string (no alternative message.)

    Note:
        This decorator produces a warning.
    """

    def _deprecated_decorator(func):
        @functools.wraps(func)
        def _deprecated(*args, **kwargs):
            message = f'The method "{func.__name__}" has been deprecated.'

            if alternative:
                message += f" {alternative}"

            warnings.warn(message, category=DeprecationWarning, stacklevel=2)
            return func(*args, **kwargs)

        return _deprecated

    return _deprecated_decorator


def obsolete(alternative: str = ""):
    """Mark a method as obsolete.

    Args:
        alternative (str, optional): A simple message describing the
            alternative implementation to the obsoleted method. Default is
            an empty string (no alternative message.)

    Note:
        This decorator produces an exception.
    """

    def _obsolete_decorator(func):
        @functools.wraps(func)
        def _obsolete(*args, **kwargs):
            message = f'The method "{func.__name__}" has been made obsolete.'

            if alternative:
                message += f" {alternative}"

            raise ObsoleteException(message) from None

        return _obsolete

    return _obsolete_decorator



"""HypoidGearSetCompoundModalAnalysisAtASpeed"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed.compound import (
    _5587,
)

_HYPOID_GEAR_SET_COMPOUND_MODAL_ANALYSIS_AT_A_SPEED = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtASpeed.Compound",
    "HypoidGearSetCompoundModalAnalysisAtASpeed",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7941,
        _7944,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
        _5513,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed.compound import (
        _5581,
        _5615,
        _5641,
        _5643,
        _5644,
        _5662,
        _5681,
    )
    from mastapy._private.system_model.part_model.gears import _2817

    Self = TypeVar("Self", bound="HypoidGearSetCompoundModalAnalysisAtASpeed")
    CastSelf = TypeVar(
        "CastSelf",
        bound="HypoidGearSetCompoundModalAnalysisAtASpeed._Cast_HypoidGearSetCompoundModalAnalysisAtASpeed",
    )


__docformat__ = "restructuredtext en"
__all__ = ("HypoidGearSetCompoundModalAnalysisAtASpeed",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_HypoidGearSetCompoundModalAnalysisAtASpeed:
    """Special nested class for casting HypoidGearSetCompoundModalAnalysisAtASpeed to subclasses."""

    __parent__: "HypoidGearSetCompoundModalAnalysisAtASpeed"

    @property
    def agma_gleason_conical_gear_set_compound_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5587.AGMAGleasonConicalGearSetCompoundModalAnalysisAtASpeed":
        return self.__parent__._cast(
            _5587.AGMAGleasonConicalGearSetCompoundModalAnalysisAtASpeed
        )

    @property
    def conical_gear_set_compound_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5615.ConicalGearSetCompoundModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed.compound import (
            _5615,
        )

        return self.__parent__._cast(_5615.ConicalGearSetCompoundModalAnalysisAtASpeed)

    @property
    def gear_set_compound_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5641.GearSetCompoundModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed.compound import (
            _5641,
        )

        return self.__parent__._cast(_5641.GearSetCompoundModalAnalysisAtASpeed)

    @property
    def specialised_assembly_compound_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5681.SpecialisedAssemblyCompoundModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed.compound import (
            _5681,
        )

        return self.__parent__._cast(
            _5681.SpecialisedAssemblyCompoundModalAnalysisAtASpeed
        )

    @property
    def abstract_assembly_compound_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5581.AbstractAssemblyCompoundModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed.compound import (
            _5581,
        )

        return self.__parent__._cast(
            _5581.AbstractAssemblyCompoundModalAnalysisAtASpeed
        )

    @property
    def part_compound_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5662.PartCompoundModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed.compound import (
            _5662,
        )

        return self.__parent__._cast(_5662.PartCompoundModalAnalysisAtASpeed)

    @property
    def part_compound_analysis(self: "CastSelf") -> "_7944.PartCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7944,
        )

        return self.__parent__._cast(_7944.PartCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7941.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7941,
        )

        return self.__parent__._cast(_7941.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def hypoid_gear_set_compound_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "HypoidGearSetCompoundModalAnalysisAtASpeed":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class HypoidGearSetCompoundModalAnalysisAtASpeed(
    _5587.AGMAGleasonConicalGearSetCompoundModalAnalysisAtASpeed
):
    """HypoidGearSetCompoundModalAnalysisAtASpeed

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _HYPOID_GEAR_SET_COMPOUND_MODAL_ANALYSIS_AT_A_SPEED

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_design(self: "Self") -> "_2817.HypoidGearSet":
        """mastapy.system_model.part_model.gears.HypoidGearSet

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def assembly_design(self: "Self") -> "_2817.HypoidGearSet":
        """mastapy.system_model.part_model.gears.HypoidGearSet

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def assembly_analysis_cases_ready(
        self: "Self",
    ) -> "List[_5513.HypoidGearSetModalAnalysisAtASpeed]":
        """List[mastapy.system_model.analyses_and_results.modal_analyses_at_a_speed.HypoidGearSetModalAnalysisAtASpeed]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyAnalysisCasesReady")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def hypoid_gears_compound_modal_analysis_at_a_speed(
        self: "Self",
    ) -> "List[_5643.HypoidGearCompoundModalAnalysisAtASpeed]":
        """List[mastapy.system_model.analyses_and_results.modal_analyses_at_a_speed.compound.HypoidGearCompoundModalAnalysisAtASpeed]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "HypoidGearsCompoundModalAnalysisAtASpeed"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def hypoid_meshes_compound_modal_analysis_at_a_speed(
        self: "Self",
    ) -> "List[_5644.HypoidGearMeshCompoundModalAnalysisAtASpeed]":
        """List[mastapy.system_model.analyses_and_results.modal_analyses_at_a_speed.compound.HypoidGearMeshCompoundModalAnalysisAtASpeed]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "HypoidMeshesCompoundModalAnalysisAtASpeed"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def assembly_analysis_cases(
        self: "Self",
    ) -> "List[_5513.HypoidGearSetModalAnalysisAtASpeed]":
        """List[mastapy.system_model.analyses_and_results.modal_analyses_at_a_speed.HypoidGearSetModalAnalysisAtASpeed]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyAnalysisCases")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_HypoidGearSetCompoundModalAnalysisAtASpeed":
        """Cast to another type.

        Returns:
            _Cast_HypoidGearSetCompoundModalAnalysisAtASpeed
        """
        return _Cast_HypoidGearSetCompoundModalAnalysisAtASpeed(self)
